@@ -1,6 +1,7 @@
 #include <SDL.h>
 #include "SFont.h"
 #include <string.h>
+#include <stdlib.h>
 
 SFont_FontInfo InternalFont;
 
@@ -46,8 +47,8 @@ void InitFont2(SFont_FontInfo *Font)
     int x = 0, i = 0;
 
     if ( Font->Surface==NULL ) {
-	printf("The font has not been loaded!\n");
-	exit(1);
+		printf("The font has not been loaded!\n");
+		exit(1);
     }
 
     if (SDL_MUSTLOCK(Font->Surface)) SDL_LockSurface(Font->Surface);
@@ -108,7 +109,7 @@ void PutString(SDL_Surface *Surface, int x, int y, char *text)
     PutString2(Surface, &InternalFont, x, y, text);
 }
 
-int TextWidth2(SFont_FontInfo *Font, char *text)
+int SFont_TextWidth2(SFont_FontInfo *Font, char *text)
 {
     int ofs=0;
     int i=0,x=0;
@@ -128,14 +129,14 @@ int TextWidth2(SFont_FontInfo *Font, char *text)
     return x;
 }
 
-int TextWidth(char *text)
+int SFont_TextWidth(char *text)
 {
-    return TextWidth2(&InternalFont, text);
+    return SFont_TextWidth2(&InternalFont, text);
 }
 
 void XCenteredString2(SDL_Surface *Surface, SFont_FontInfo *Font, int y, char *text)
 {
-    PutString2(Surface, Font, Surface->w/2-TextWidth2(Font,text)/2, y, text);
+    PutString2(Surface, Font, Surface->w/2-SFont_TextWidth2(Font,text)/2, y, text);
 }
 
 void XCenteredString(SDL_Surface *Surface, int y, char *text)
@@ -179,7 +180,7 @@ void SFont_InternalInput( SDL_Surface *Dest, SFont_FontInfo *Font, int x, int y,
 		    text[strlen(text)-1]='\0';
 		else if (ch!='\b')
 		    sprintf(text,"%s%c",text,ch);
-	        if (TextWidth2(Font,text)>PixelWidth) text[strlen(text)-1]='\0';
+	        if (SFont_TextWidth2(Font,text)>PixelWidth) text[strlen(text)-1]='\0';
 		SDL_BlitSurface( Back, NULL, Dest, &rect);
 		PutString2(Dest, Font, x, y, text);
 		SDL_UpdateRects(Dest, 1, &rect);
@@ -191,9 +192,9 @@ void SFont_InternalInput( SDL_Surface *Dest, SFont_FontInfo *Font, int x, int y,
 	    blink=1-blink;
 	    blinktimer=SDL_GetTicks()+500;
 	    if (blink) {
-		PutString2(Dest, Font, x+TextWidth2(Font,text), y, "|");
+		PutString2(Dest, Font, x+SFont_TextWidth2(Font,text), y, "|");
 		SDL_UpdateRects(Dest, 1, &rect);
-//		SDL_UpdateRect(Dest, x+TextWidth2(Font,text), y, TextWidth2(Font,"|"), Font->Surface->h);
+//		SDL_UpdateRect(Dest, x+SFont_TextWidth2(Font,text), y, SFont_TextWidth2(Font,"|"), Font->Surface->h);
 	    } else {
 		SDL_BlitSurface( Back, NULL, Dest, &rect);
 		PutString2(Dest, Font, x, y, text);
