@@ -32,8 +32,8 @@ void PutString (SDL_Surface *Surface, int x, int y, char *text);
 void PutString2(SDL_Surface *Surface, SFont_FontInfo *Font, int x, int y, char *text);
 
 // Returns the width of "text" in pixels
-int TextWidth(char *text);
-int TextWidth2(SFont_FontInfo *Font, char *text);
+int SFont_TextWidth(char *text);
+int SFont_TextWidth2(SFont_FontInfo *Font, char *text);
 
 // Blits a string to with centered x position
 void XCenteredString (SDL_Surface *Surface, int y, char *text);
@@ -45,4 +45,4 @@ void XCenteredString2(SDL_Surface *Surface, SFont_FontInfo *Font, int y, char *t
 void SFont_Input ( SDL_Surface *Destination, int x, int y, int Width, char *text);
 void SFont_Input2( SDL_Surface *Destination, SFont_FontInfo *Font, int x, int y, int Width, char *text);
 
-Uint32 GetPixel(SDL_Surface *Surface, Sint32 X, Sint32 Y);
+extern Uint32 GetPixel(SDL_Surface *Surface, Sint32 X, Sint32 Y);
