@@ -15,7 +15,7 @@ void AddScore(int ScoreBonus)
     sprintf(text, "Score: %d", Score);
     rect.x=0;
     rect.y=0;
-    rect.w=TextWidth(text)+30;
+    rect.w=SFont_TextWidth(text)+30;
     rect.h=Font->h;
     SDL_BlitSurface( BackPic, &rect, BackBuffer, &rect);
     PutString(BackBuffer,0,0,text);
@@ -171,9 +171,9 @@ void DrawCenteredText(int y, char *text)
 {
     SDL_Rect rect;
 
-    rect.x=400-TextWidth(text)/2;
+    rect.x=400-SFont_TextWidth(text)/2;
     rect.y=y;
-    rect.w=TextWidth(text);
+    rect.w=SFont_TextWidth(text);
     rect.h=Font->h;
     SDL_SetAlpha(BackBuffer,(SDL_SRCALPHA), 255);
     SDL_BlitSurface( BackBuffer, &rect, Screen, &rect);
@@ -229,9 +229,9 @@ void StartWave()
     AddScore(0);
     Blit(0,0,BackBuffer);
     sprintf(text,"Starting Wave #%d",WaveNum+1);
-    PutString(Screen, 400-TextWidth(text)/2, 170, text);
+    PutString(Screen, 400-SFont_TextWidth(text)/2, 170, text);
     sprintf(text,"Score %d x",WaveNum/2+1);
-    PutString(Screen, 400-TextWidth(text)/2, 220, text);
+    PutString(Screen, 400-SFont_TextWidth(text)/2, 220, text);
     DrawCenteredText(370, "Defend Cities!");
     for (i=0;i<3;i++) {
 	if ( CannonDestroyed[i] ) {
@@ -291,7 +291,7 @@ void WaveScoring()
     WaitWithMouse(3000-ArcadeMode*1500);
     Now=SDL_GetTicks();
 //    sprintf(text,"Starting Wave #%d",WaveNum+1);
-//    PutString(Screen, 400-TextWidth(text)/2, 300, text);
+//    PutString(Screen, 400-SFont_TextWidth(text)/2, 300, text);
 }
 
 void ProcessEvents()
@@ -430,7 +430,7 @@ void StartGame()
         //SDL_Delay(60);
     }
 #ifdef USE_SOUND
-    Mix_FadeOutMusic(4000);
+//    Mix_FadeOutMusic(4000);
 #endif
     PlaySound(GameoverSound);
     i=0;
