@@ -23,6 +23,7 @@
 */                                                                            
 #include <main.h>
 #include <time.h> /* For seeding rand() */
+#include <string.h>
 #ifdef JOYSTICK
 #include "joystick.h"
 #endif
@@ -101,12 +102,12 @@ int Button(int x, int y, char *String, int prev, SDL_Surface *Background)
     
     rect.x=x;
     rect.y=y;
-    rect.w=TextWidth(String);
+    rect.w=SFont_TextWidth(String);
     rect.h=Font->h;
     
     SDL_GetMouseState(&MouseX, &MouseY);
     if ((MouseX>x)&&(MouseY>y)
-	&&(MouseX<x+TextWidth(String))
+	&&(MouseX<x+SFont_TextWidth(String))
 	&&(MouseY<y+Font->h))
     {
 	if (prev!=1) {
@@ -159,8 +160,8 @@ void ShowHelp()
     SDL_Rect rect;
     SDL_Event WaitEvent;
     char DetailString[100],LevelString[100],text[100];
-    int Detail=3,Level=3,SoundV=3,MusicV=3;
-
+    int Level=3,SoundV=3,MusicV=3;
+	
     Blit(0,0,BackPic);
     ExplosionCount=0;
     XCenteredString(Screen,10,"< Penguin Command Help & Options >");
@@ -178,123 +179,101 @@ void ShowHelp()
     SDL_BlitSurface(Screen,NULL,FadeBuffer,NULL);
     Update();
     Now=SDL_GetTicks();
-    while ((Detail)||(Level)||(SoundV)||(MusicV)) {
-	while (   (SDL_GetMouseState(NULL,NULL)==SDL_BUTTON(1))
-		||(SDL_GetMouseState(NULL,NULL)==SDL_BUTTON(2))
-		||(SDL_GetMouseState(NULL,NULL)==SDL_BUTTON(3)) )
+    while (Level || SoundV || MusicV) {
+		SDL_PollEvent(&WaitEvent);
+		while (   (SDL_GetMouseState(NULL,NULL)==SDL_BUTTON(1))
+				  ||(SDL_GetMouseState(NULL,NULL)==SDL_BUTTON(2))
+				  ||(SDL_GetMouseState(NULL,NULL)==SDL_BUTTON(3)) )
 	    {SDL_PollEvent(&WaitEvent);}
-        while ((WaitEvent.type!=SDL_KEYDOWN)&&(WaitEvent.type!=SDL_MOUSEBUTTONDOWN)) {
+        while (WaitEvent.type!=SDL_KEYDOWN && WaitEvent.type!=SDL_MOUSEBUTTONDOWN) {
     	    SDL_PollEvent(&WaitEvent);
-	    UndrawMouse();
-	    // Explosion
-	    UndrawExplosion();
-	    if (ExplosionCount<1) CreateExplosion(80,235);
-	    HandleExplosion(0);
-	    DrawExplosion();
-	    // Bomb
-	    anim+=Speed/100;
-	    if ((int)anim>=10) anim-=10;
-	    rect.x=80-BombPic[0]->w/2; rect.y=270-BombPic[0]->h/2;
-	    rect.w=BombPic[0]->w; rect.h=BombPic[0]->h;
-	    SDL_BlitSurface( BackBuffer, &rect, Screen, &rect);
-	    Blit(rect.x,rect.y,BombPic[(int)anim]);
-	    AddThisRect(blitrect);
-	    // detail button
-	    if (LowDetail) strcpy(DetailString,"Low Detail");
-	    if (MediumDetail) strcpy(DetailString,"Medium Detail");
-	    if (HighDetail) strcpy(DetailString,"High Detail");
-	    Detail=Button(400-TextWidth(DetailString)/2,430,DetailString,Detail,FadeBuffer);
-	    // level start button
-	    sprintf(LevelString,"Starting at Wave %d", StartLevel+1);
-	    Level=Button(400-TextWidth(LevelString)/2,470,LevelString,Level,FadeBuffer);
-	    // sound buttons
-	    sprintf(text,"Music Volume: %d", MusicVol);
-	    MusicV=Button(390-TextWidth(text),510,text,MusicV,FadeBuffer);
-	    sprintf(text,"Sound Volume: %d", SoundVol);
-	    SoundV=Button(410,510,text,SoundV,FadeBuffer);
-	    // display
-	    GetSpeed();
-	    DrawMouse();
-	    Update();
-	}
-	if (SoundV) {
-	    if (SDL_GetMouseState(NULL,NULL)==SDL_BUTTON(1))
-		if (SoundVol<15) SoundVol++;
-	    if (SDL_GetMouseState(NULL,NULL)==SDL_BUTTON(3))
-		if (SoundVol>0) SoundVol--;
-	    SoundV=3;
-	    rect.x=400;
-	    rect.y=510;
-	    rect.w=400;
-	    rect.h=Font->h;
-	    AddThisRect(rect);
+			UndrawMouse();
+			// Explosion
+			UndrawExplosion();
+			if (ExplosionCount<1) CreateExplosion(80,235);
+			HandleExplosion(0);
+			DrawExplosion();
+			// Bomb
+			anim+=Speed/100;
+			if ((int)anim>=10) anim-=10;
+			rect.x=80-BombPic[0]->w/2; rect.y=270-BombPic[0]->h/2;
+			rect.w=BombPic[0]->w; rect.h=BombPic[0]->h;
+			SDL_BlitSurface( BackBuffer, &rect, Screen, &rect);
+			Blit(rect.x,rect.y,BombPic[(int)anim]);
+			AddThisRect(blitrect);
+			// detail button
+			if (LowDetail) strcpy(DetailString,"Low Detail");
+			if (MediumDetail) strcpy(DetailString,"Medium Detail");
+			if (HighDetail) strcpy(DetailString,"High Detail");
+			//	    Detail=Button(400-SFont_TextWidth(DetailString)/2,430,DetailString,Detail,FadeBuffer);
+			// level start button
+			sprintf(LevelString,"Starting at Wave %d", StartLevel+1);
+			Level=Button(400-SFont_TextWidth(LevelString)/2,430,LevelString,Level,FadeBuffer);
+			// sound buttons
+			sprintf(text,"Music Volume: %d", MusicVol);
+			MusicV=Button(390-SFont_TextWidth(text),490,text,MusicV,FadeBuffer);
+			sprintf(text,"Sound Volume: %d", SoundVol);
+			SoundV=Button(410,490,text,SoundV,FadeBuffer);
+			// display
+			GetSpeed();
+			DrawMouse();
+			Update();
+		}
+		if (SoundV) {
+			if (SDL_GetMouseState(NULL,NULL)==SDL_BUTTON(1))
+				if (SoundVol<15) SoundVol++;
+			if (SDL_GetMouseState(NULL,NULL)==SDL_BUTTON(3))
+				if (SoundVol>0) SoundVol--;
+			SoundV=3;
+			rect.x=400;
+			rect.y=490;
+			rect.w=400;
+			rect.h=Font->h;
+			AddThisRect(rect);
             SDL_SetAlpha( FadeBuffer, 0, 0);
-	    SDL_BlitSurface( FadeBuffer, &rect, BackBuffer, &rect);
-	    SDL_BlitSurface( FadeBuffer, &rect, Screen, &rect);
-	    SetVol();
-	}
-	if (MusicV) {
-	    if (SDL_GetMouseState(NULL,NULL)==SDL_BUTTON(1))
-		if (MusicVol<15) MusicVol++;
-	    if (SDL_GetMouseState(NULL,NULL)==SDL_BUTTON(3))
-		if (MusicVol>0) MusicVol--;
-	    MusicV=3;
-	    rect.x=0;
-	    rect.y=510;
-	    rect.w=400;
-	    rect.h=Font->h;
-	    AddThisRect(rect);
+			SDL_BlitSurface( FadeBuffer, &rect, BackBuffer, &rect);
+			SDL_BlitSurface( FadeBuffer, &rect, Screen, &rect);
+			SetVol();
+		}
+		if (MusicV) {
+			if (SDL_GetMouseState(NULL,NULL)==SDL_BUTTON(1))
+				if (MusicVol<15) MusicVol++;
+			if (SDL_GetMouseState(NULL,NULL)==SDL_BUTTON(3))
+				if (MusicVol>0) MusicVol--;
+			MusicV=3;
+			rect.x=0;
+			rect.y=490;
+			rect.w=400;
+			rect.h=Font->h;
+			AddThisRect(rect);
             SDL_SetAlpha( FadeBuffer, 0, 0);
-	    SDL_BlitSurface( FadeBuffer, &rect, BackBuffer, &rect);
-	    SDL_BlitSurface( FadeBuffer, &rect, Screen, &rect);
+			SDL_BlitSurface( FadeBuffer, &rect, BackBuffer, &rect);
+			SDL_BlitSurface( FadeBuffer, &rect, Screen, &rect);
 #ifdef USE_SOUND
-	    Mix_VolumeMusic(MusicVol*7);
+			Mix_VolumeMusic(MusicVol*7);
 #endif
-	}
-	if (Level) {
-	    if (SDL_GetMouseState(NULL,NULL)==SDL_BUTTON(1))
-		if (StartLevel<30) StartLevel+=5;
-	    if (SDL_GetMouseState(NULL,NULL)==SDL_BUTTON(3))
-		if (StartLevel>0) StartLevel-=5;
-	    Level=3;
-	    rect.x=100;
-	    rect.y=470;
-	    rect.w=600;
-	    rect.h=Font->h;
+		}
+		if (Level) {
+			if (SDL_GetMouseState(NULL,NULL)==SDL_BUTTON(1))
+				if (StartLevel<30) StartLevel+=5;
+			if (SDL_GetMouseState(NULL,NULL)==SDL_BUTTON(3))
+				if (StartLevel>0) StartLevel-=5;
+			Level=3;
+			rect.x=100;
+			rect.y=430;
+			rect.w=600;
+			rect.h=Font->h;
             SDL_SetAlpha( FadeBuffer, 0, 0);
-	    SDL_BlitSurface( FadeBuffer, &rect, BackBuffer, &rect);
-	    SDL_BlitSurface( FadeBuffer, &rect, Screen, &rect);
-	    AddThisRect(rect);
-	}
-	if (Detail) {
-	    if (HighDetail) {
-		HighDetail=0;
-		LowDetail=1;
-	    } else
-	    if (MediumDetail) {
-		MediumDetail=0;
-		HighDetail=1;
-	    } else
-	    if (LowDetail) {
-		LowDetail=0;
-		MediumDetail=1;
-	    }
-	    Detail=3;
-	    rect.x=100;
-	    rect.y=430;
-	    rect.w=600;
-	    rect.h=Font->h;
-            SDL_SetAlpha( FadeBuffer, 0, 0);
-	    SDL_BlitSurface( FadeBuffer, &rect, BackBuffer, &rect);
-	    SDL_BlitSurface( FadeBuffer, &rect, Screen, &rect);
-	    AddThisRect(rect);
-	}
-	SDL_Delay(10);
-	while (SDL_GetMouseState(NULL,NULL)==SDL_BUTTON(1)) {SDL_PollEvent(&WaitEvent);SDL_Delay(10);}
+			SDL_BlitSurface( FadeBuffer, &rect, BackBuffer, &rect);
+			SDL_BlitSurface( FadeBuffer, &rect, Screen, &rect);
+			AddThisRect(rect);
+		}
+		SDL_Delay(10);
+		while (SDL_GetMouseState(NULL,NULL)==SDL_BUTTON(1)) {SDL_PollEvent(&WaitEvent);SDL_Delay(10);}
     }
-    SetDetail();
-    LoadImages();
-    SDL_ShowCursor(HWCursor);
+	//    SetDetail();
+	//    LoadImages();
+	//    SDL_ShowCursor(HWCursor);
 }
 
 void ShowCredits()
@@ -349,6 +328,7 @@ void ShowTitle()
 	Loaded=1;
 	MenuEvents();
     }
+	SDL_SetAlpha(Font, SDL_SRCALPHA, 0);
     ExplosionCount=0;CursorAnim=0;
     SDL_BlitSurface(TitlePic,NULL,BackBuffer,NULL);
     // menu
@@ -363,10 +343,10 @@ void ShowTitle()
 	}
 	UndrawMouse();
 	hiscore=Button(50,300,"Hiscores",hiscore,TitlePic);
-	start=Button(400-TextWidth("Normal Game")/2,300,"Normal Game",start,TitlePic);
-	arcade=Button(400-TextWidth("Arcade Game")/2,340,"Arcade Game",arcade,TitlePic);
-	help=Button(750-TextWidth("Help&Conf"),300,"Help&Conf",help,TitlePic);
-	credits=Button(750-TextWidth("Credits"),450,"Credits",credits,TitlePic);
+	start=Button(400-SFont_TextWidth("Normal Game")/2,300,"Normal Game",start,TitlePic);
+	arcade=Button(400-SFont_TextWidth("Arcade Game")/2,340,"Arcade Game",arcade,TitlePic);
+	help=Button(750-SFont_TextWidth("Help&Conf"),300,"Help&Conf",help,TitlePic);
+	credits=Button(750-SFont_TextWidth("Credits"),450,"Credits",credits,TitlePic);
 	quit=Button(50,450,"Quit",quit,TitlePic);
 	// Fancy explosions
 	UndrawExplosion();
@@ -438,17 +418,12 @@ void ReadCommandLine(char *argv[])
 
 int main(int argc, char *argv[])
 {
-    SDL_Surface *Icon;
-
 // intialisation
 //    if ( SDL_Init(SDL_INIT_AUDIO ) < 0 ) ComplainAndExit();
     ReadCommandLine(argv);
     printf("** Starting SDL init **\n");
     init_SDL();
     SDL_EventState(SDL_ACTIVEEVENT, SDL_IGNORE);
-    printf("** Loading Icon **\n");
-    Icon = LoadImage("icon.png",-1);
-    SDL_WM_SetIcon(Icon, NULL);
     SDL_WM_SetCaption("Penguin Command","Penguin Command");
     srand((unsigned)time(NULL));
 #ifdef JOYSTICK
@@ -459,7 +434,6 @@ int main(int argc, char *argv[])
 // load data
     printf("** Loading Title Screen **\n");
     TitlePic = LoadImage("title.jpg",0);
-    printf("** Loading Sounds **\n");
     InitSound();
 // set volume
     ReadOptions();
@@ -467,24 +441,25 @@ int main(int argc, char *argv[])
     printf("** Playing Music **\n");
     SetVol();
     SDL_EnableUNICODE(1);
-    LoadCursor();
-    SetDetail();
+//    LoadCursor();
+//    SetDetail();
     SDL_ShowCursor(HWCursor);
     printf("** Ready to enter Menu **\n");
 // start game
+	PlayMusic();
     while (!Quit) {
 #ifdef USE_SOUND
-	if (sound) {
-	    printf("** Fade in Music **\n");    
-	    Mix_FadeInMusic(Music[abrand(0,MUSICNUM-1)],0,5000);
-	}
+		if (sound) {
+			printf("** Fade in Music **\n");
+			//Mix_FadeInMusic(Music[abrand(0,MUSICNUM-1)],0,5000);
+		}
 #endif
-	printf("** Showing Title Screen **\n");
-	ShowTitle();
-	if (Quit) break;
-	StartGame();
-	FinalScore();
-	ShowHiscore();
+		printf("** Showing Title Screen **\n");
+		ShowTitle();
+		if (Quit) break;
+		StartGame();
+		FinalScore();
+		ShowHiscore();
     }
 // user wants to quit
 #ifdef USE_SOUND
