@@ -3,17 +3,17 @@
 #include <SDL.h>
 #include <SDL_timer.h>
 #include <math.h>
-#include <gfx.h>
-#include <game.h>
-#include <missile.h>
-#include <shot.h>
-#include <explosion.h>
-#include <SFont.h>
-#include <wave.h>
-#include <sound.h>
-#include <bomb.h>
-#include <options.h>
-#include <mouse.h>
+#include "gfx.h"
+#include "game.h"
+#include "missile.h"
+#include "shot.h"
+#include "explosion.h"
+#include "SFont.h"
+#include "wave.h"
+#include "sound.h"
+#include "bomb.h"
+#include "options.h"
+#include "mouse.h"
 
 extern int fullscreen,CityDestroyed[6],CannonDestroyed[3],Score,Quit,HWCursor,NoAlpha,StartLevel,ArcadeMode;
 extern int SoundVol,MusicVol;
@@ -25,4 +25,4 @@ extern SDL_Event event;
 
 extern int Wait( int time_in_ms );
 
-#define JOYSTICK 1
+//#define JOYSTICK 1
